==> camel-cdi-2.12-20130829.143834-190-sources.jar: org/apache/camel/cdi/CdiCamelContext.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.cdi;

import javax.annotation.PostConstruct;
import javax.annotation.PreDestroy;
import javax.enterprise.inject.Instance;
import javax.inject.Inject;

import org.apache.camel.impl.DefaultCamelContext;
import org.apache.camel.spi.Injector;
import org.apache.camel.spi.Registry;
import org.apache.camel.util.ObjectHelper;

/**
 * CDI {@link org.apache.camel.CamelContext} class.
 */
public class CdiCamelContext extends DefaultCamelContext {

    public CdiCamelContext() {
        super(new CdiBeanRegistry());
        setInjector(new CdiInjector(getInjector()));
    }

    @Inject
    public void setRegistry(Instance<Registry> instance) {
        if (isSingular(instance)) {
            setRegistry(instance.get());
        }
    }

    @Inject
    public void setInjector(Instance<Injector> instance) {
        if (isSingular(instance)) {
            setInjector(instance.get());
        }
    }

    private <T> boolean isSingular(Instance<T> instance) {
        return !instance.isUnsatisfied() && !instance.isAmbiguous();
    }

    @PostConstruct
    @Override
    public void start() {
        try {
            super.start();
        } catch (Exception e) {
            ObjectHelper.wrapRuntimeCamelException(e);
        }
    }

    @PreDestroy
    @Override
    public void stop() {
        try {
            super.stop();
        } catch (Exception e) {
            ObjectHelper.wrapRuntimeCamelException(e);
        }
    }

}

==> camel-cdi-2.20.2-sources.jar: org/apache/camel/cdi/CdiCamelContext.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.cdi;

import org.apache.camel.impl.DefaultCamelContext;

/**
 * CDI {@link org.apache.camel.CamelContext} class that can be extended
 * to declare custom Camel context beans. Camel CDI is capable of managing
 * any bean that implements {@code org.apache.camel.CamelContext},
 * so that directly extending {@link org.apache.camel.impl.DefaultCamelContext}
 * is an option to avoid having to depend on Camel CDI specific API, e.g.:
 *
 * <pre><code>
 * {@literal @}ApplicationScoped
 * {@literal @}ContextName("foo")
 * public class FooCamelContext extends DefaultCamelContext {
 * }
 * </code></pre>
 */
@Vetoed
public class CdiCamelContext extends DefaultCamelContext {

}
